@@ -12,8 +12,8 @@ class ShooterResults:
 
     def summary(self):
         parts = list()
-        parts.append("Summary:\n")
-        parts.append('Codes: {}'.format(', '.join([
+        parts.append("\nBotank simulation summary:\n")
+        parts.append('Codes: {}\n'.format(', '.join([
             '{} - {}'.format(k, v)
             for k, v in Counter(self.codes).most_common()
         ])))
@@ -28,9 +28,11 @@ class ShooterResults:
 
     def write_to_disk(self, filename):
         with open(filename, 'w', encoding='utf-8') as f:
-            json.dump({
-                'requests': self.requests,
-                'responses': self.responses,
-                'times': self.times,
-                'codes': self.codes,
-            }, f)
+            for i in range(len(self.requests)):
+                json.dump({
+                    'request': self.requests[i],
+                    'response': self.responses[i],
+                    'time': self.times[i],
+                    'code': self.codes[i],
+                }, f, ensure_ascii=False)
+                f.write('\n')
